pub trait Nested<T> {
// Required method
fn unnest(self) -> T;
}Expand description
Nested is implemented on builder types to enable passing them directly into other builders without needing to call build().
pub trait Nested<T> {
// Required method
fn unnest(self) -> T;
}Nested is implemented on builder types to enable passing them directly into other builders without needing to call build().